@@ -1,5 +1,5 @@
 package Geo::Address::Formatter;
-$Geo::Address::Formatter::VERSION = '1.997';
+$Geo::Address::Formatter::VERSION = '1.998';
 # ABSTRACT: take structured address data and format it according to the various global/country rules
 
 use strict;
@@ -56,8 +56,14 @@ sub _read_configuration {
     my $path = shift;
 
     return if (! -e $path);
+    my $compyaml = $path . '/components.yaml';
+    return if (! -e $compyaml);
 
-    my @a_filenames = File::Find::Rule->file()->name('*.yaml')->in($path . '/countries');
+    my @a_filenames = File::Find::Rule
+        ->new
+        ->maxdepth(1)
+        ->name('*.yaml')
+        ->in($path . '/countries');
 
     $self->{templates}          = {};
     $self->{component_aliases}  = {};
@@ -86,7 +92,7 @@ sub _read_configuration {
     # see if we can load the components
     try {
         say STDERR "loading components" if ($debug);
-        my @c = LoadFile($path . '/components.yaml');
+        my @c = LoadFile($compyaml);
 
         if ($debug){
             say STDERR Dumper \@c;
@@ -140,7 +146,11 @@ sub _read_configuration {
     }
 
     # get the abbreviations
-    my @abbrv_filenames = File::Find::Rule->file()->name('*.yaml')->in($path . '/abbreviations');
+    my @abbrv_filenames = File::Find::Rule
+        ->new
+        ->maxdepth(1)        
+        ->name('*.yaml')
+        ->in($path . '/abbreviations');
 
     # read the config files
     foreach my $abbrv_file (@abbrv_filenames) {
@@ -948,7 +958,7 @@ Geo::Address::Formatter - take structured address data and format it according t
 
 =head1 VERSION
 
-version 1.997
+version 1.998
 
 =head1 SYNOPSIS
 
@@ -978,7 +988,7 @@ I<debug>: prints tons of debugging info for use in development.
 
 I<no_warnings>: turns off a few warnings if configuration is not optimal.
 
-I<only_address>: formatted will only contain known components (will not include POI names like). Note, can be overridden with optional param to format_address method.
+I<only_address>: formatted will only contain known components (will not include POI names). Note, can be overridden with optional param to format_address method.
 
 =head2 final_components
 
